import typescript from 'typescript';
import { R as RemoteOptions, H as HostOptions, a as RemoteInfo } from './HostOptions-cf22e0ab.js';
import { D as DTSManagerOptions } from './DTSManagerOptions-3369791f.js';
import { ChildProcess } from 'child_process';
import '@module-federation/sdk';

declare const retrieveRemoteConfig: (options: RemoteOptions) => {
    tsConfig: typescript.CompilerOptions;
    mapComponentsToExpose: Record<string, string>;
    remoteOptions: Required<RemoteOptions>;
};

declare const retrieveHostConfig: (options: HostOptions) => {
    hostOptions: Required<HostOptions>;
    mapRemotesToDownload: Record<string, RemoteInfo>;
};

declare const REMOTE_ALIAS_IDENTIFIER = "REMOTE_ALIAS_IDENTIFIER";
declare const REMOTE_API_TYPES_FILE_NAME = "apis.d.ts";
declare const HOST_API_TYPES_FILE_NAME = "index.d.ts";
declare const enum UpdateMode {
    POSITIVE = "POSITIVE",
    PASSIVE = "PASSIVE"
}

interface UpdateTypesOptions {
    updateMode: UpdateMode;
    remoteName?: string;
    remoteTarPath?: string;
}
declare class DTSManager {
    options: DTSManagerOptions;
    runtimePkgs: string[];
    remoteAliasMap: Record<string, Required<RemoteInfo>>;
    loadedRemoteAPIAlias: string[];
    extraOptions: Record<string, any>;
    constructor(options: DTSManagerOptions);
    generateAPITypes(mapComponentsToExpose: Record<string, string>): string;
    extractRemoteTypes(options: ReturnType<typeof retrieveRemoteConfig>): Promise<void>;
    generateTypes(): Promise<void>;
    requestRemoteManifest(remoteInfo: RemoteInfo): Promise<Required<RemoteInfo>>;
    consumeTargetRemotes(hostOptions: Required<HostOptions>, remoteInfo: Required<RemoteInfo>): Promise<[string, string] | undefined>;
    downloadAPITypes(remoteInfo: Required<RemoteInfo>, destinationPath: string): Promise<void>;
    consumeAPITypes(hostOptions: Required<HostOptions>): void;
    consumeArchiveTypes(options: HostOptions): Promise<{
        hostOptions: Required<HostOptions>;
        downloadPromisesResult: PromiseSettledResult<[string, string] | undefined>[];
    }>;
    consumeTypes(): Promise<void>;
    updateTypes(options: UpdateTypesOptions): Promise<void>;
}

declare function getDTSManagerConstructor(implementation?: string): typeof DTSManager;
declare const validateOptions: (options: HostOptions) => void;
declare function retrieveTypesAssetsInfo(options: RemoteOptions): {
    apiTypesPath: string;
    zipTypesPath: string;
    zipName: string;
    apiFileName: string;
};

declare const retrieveMfTypesPath: (tsConfig: typescript.CompilerOptions, remoteOptions: Required<RemoteOptions>) => string;
declare const retrieveOriginalOutDir: (tsConfig: typescript.CompilerOptions, remoteOptions: Required<RemoteOptions>) => string;

declare const retrieveTypesZipPath: (mfTypesPath: string, remoteOptions: Required<RemoteOptions>) => string;

declare function generateTypes(options: DTSManagerOptions): Promise<void>;

declare function generateTypesInChildProcess(options: DTSManagerOptions): Promise<void>;

declare function consumeTypes(options: DTSManagerOptions): Promise<void>;

declare function exposeRpc(fn: (...args: any[]) => any): void;

declare enum RpcGMCallTypes {
    CALL = "mf_call",
    RESOLVE = "mf_resolve",
    REJECT = "mf_reject",
    EXIT = "mf_exit"
}
interface RpcCallMessage {
    type: RpcGMCallTypes.CALL;
    id: string;
    args: unknown[];
}
interface RpcResolveMessage {
    type: RpcGMCallTypes.RESOLVE;
    id: string;
    value: unknown;
}
interface RpcRejectMessage {
    type: RpcGMCallTypes.REJECT;
    id: string;
    error: unknown;
}
interface RpcExitMessage {
    type: RpcGMCallTypes.EXIT;
    id: string;
}
type RpcMessage = RpcCallMessage | RpcResolveMessage | RpcRejectMessage | RpcExitMessage;
type RpcMethod = (...args: any[]) => any;
type RpcRemoteMethod<T extends RpcMethod> = T extends (...args: infer A) => infer R ? R extends Promise<any> ? (...args: A) => R : (...args: A) => Promise<R> : (...args: unknown[]) => Promise<unknown>;

interface WrapRpcOptions {
    id: string;
    once?: boolean;
}
declare function wrapRpc<T extends (...args: any[]) => any>(childProcess: ChildProcess, options: WrapRpcOptions): RpcRemoteMethod<T>;

interface RpcWorkerBase {
    connect(...args: unknown[]): any;
    terminate(): void;
    readonly connected: boolean;
    readonly id: string;
    readonly process: ChildProcess | undefined;
}
type RpcWorker<T extends RpcMethod = RpcMethod> = RpcWorkerBase & RpcRemoteMethod<T>;
declare function createRpcWorker<T extends RpcMethod>(modulePath: string, data: unknown, memoryLimit?: number, once?: boolean): RpcWorker<T>;
declare function getRpcWorkerData(): unknown;

declare class RpcExitError extends Error {
    readonly code?: string | number | null | undefined;
    readonly signal?: string | null | undefined;
    constructor(message: string, code?: string | number | null | undefined, signal?: string | null | undefined);
}

type index_RpcCallMessage = RpcCallMessage;
type index_RpcExitError = RpcExitError;
declare const index_RpcExitError: typeof RpcExitError;
type index_RpcGMCallTypes = RpcGMCallTypes;
declare const index_RpcGMCallTypes: typeof RpcGMCallTypes;
type index_RpcMessage = RpcMessage;
type index_RpcMethod = RpcMethod;
type index_RpcRejectMessage = RpcRejectMessage;
type index_RpcRemoteMethod<T extends RpcMethod> = RpcRemoteMethod<T>;
type index_RpcResolveMessage = RpcResolveMessage;
type index_RpcWorker<T extends RpcMethod = RpcMethod> = RpcWorker<T>;
declare const index_createRpcWorker: typeof createRpcWorker;
declare const index_exposeRpc: typeof exposeRpc;
declare const index_getRpcWorkerData: typeof getRpcWorkerData;
declare const index_wrapRpc: typeof wrapRpc;
declare namespace index {
  export {
    index_RpcCallMessage as RpcCallMessage,
    index_RpcExitError as RpcExitError,
    index_RpcGMCallTypes as RpcGMCallTypes,
    index_RpcMessage as RpcMessage,
    index_RpcMethod as RpcMethod,
    index_RpcRejectMessage as RpcRejectMessage,
    index_RpcRemoteMethod as RpcRemoteMethod,
    index_RpcResolveMessage as RpcResolveMessage,
    index_RpcWorker as RpcWorker,
    index_createRpcWorker as createRpcWorker,
    index_exposeRpc as exposeRpc,
    index_getRpcWorkerData as getRpcWorkerData,
    index_wrapRpc as wrapRpc,
  };
}

export { DTSManager, DTSManagerOptions, HOST_API_TYPES_FILE_NAME, HostOptions, REMOTE_ALIAS_IDENTIFIER, REMOTE_API_TYPES_FILE_NAME, RemoteOptions, UpdateMode, consumeTypes, generateTypes, generateTypesInChildProcess, getDTSManagerConstructor, retrieveHostConfig, retrieveMfTypesPath, retrieveOriginalOutDir, retrieveRemoteConfig, retrieveTypesAssetsInfo, retrieveTypesZipPath, index as rpc, validateOptions };
